==> bigloo2.0a.tar.gz: bigloo2.0a/comptime/Type/cache.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Type/cache.scm              */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Jan 18 11:28:43 1995                          */
;*    Last change :  Fri Feb  6 16:48:12 1998 (serrano)                */
;*    -------------------------------------------------------------    */
;*    A small type cache to avoid to many lookup in Tenv.              */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module type_cache
   (import type_type
	   type_env)
   (export (install-type-cache!)
           *obj*
           *cobj*
	   *cell*
	   *magic*
	   *void*
	   *bint*
	   *int*
	   *long*
	   *bool*
	   *bbool*
	   *real*
	   *char*
	   *bnil*
	   *pair*
	   *string*
	   *bstring*
	   *symbol*
	   *keyword*
	   *vector*
	   *struct*
	   *unspec*
	   *procedure*
	   *exit*
	   *_*
	   (get-default-type::type)
	   (set-default-type! ::type)
	   (get-object-type)))

;*---------------------------------------------------------------------*/
;*    install-type-cache! ...                                          */
;*---------------------------------------------------------------------*/
(define (install-type-cache!)
   (set! *obj*        (use-type! 'obj))
   (set! *cobj*       (use-type! 'cobj))
   (set! *cell*       (use-type! 'cell))
   (set! *magic*      (use-type! 'magic))
   (set! *void*       (use-type! 'void))
   (set! *bint*       (use-type! 'bint))
   (set! *int*        (use-type! 'int))
   (set! *long*       (use-type! 'long))
   (set! *bool*       (use-type! 'bool))
   (set! *bbool*      (use-type! 'bbool))
   (set! *real*       (use-type! 'double))
   (set! *char*       (use-type! 'uchar))
   (set! *pair*       (use-type! 'pair))
   (set! *bnil*       (use-type! 'nil))
   (set! *string*     (use-type! 'string))
   (set! *bstring*    (use-type! 'bstring))
   (set! *symbol*     (use-type! 'symbol))
   (set! *keyword*    (use-type! 'keyword))
   (set! *vector*     (use-type! 'vector))
   (set! *struct*     (use-type! 'struct))
   (set! *procedure*  (use-type! 'procedure))
   (set! *unspec*     (use-type! 'unspecified))
   (set! *exit*       (use-type! 'exit))
   (set! *object*     (if (type-exists? 'object)
			  (find-type 'object)
			  #f))
   (set! *_*          (use-type! '_))
   (set! *default-type* *_*))

;*---------------------------------------------------------------------*/
;*    The register cache                                               */
;*---------------------------------------------------------------------*/
(define *obj*          'no-type-yet)
(define *cobj*         'no-type-yet)
(define *cell*         'no-type-yet)
(define *magic*        'no-type-yet)
(define *void*         'no-type-yet)
(define *bint*         'no-type-yet)
(define *int*          'no-type-yet)
(define *long*         'no-type-yet)
(define *bool*         'no-type-yet)
(define *bbool*        'no-type-yet)
(define *real*         'no-type-yet)
(define *char*         'no-type-yet)
(define *string*       'no-type-yet)
(define *bstring*      'no-type-yet)
(define *symbol*       'no-type-yet)
(define *keyword*      'no-type-yet)
(define *pair*         'no-type-yet)
(define *bnil*         'no-type-yet)
(define *vector*       'no-type-yet)
(define *struct*       'no-type-yet)
(define *procedure*    'no-type-yet)
(define *unspec*       'no-type-yet)
(define *exit*         'no-type-yet)
(define *object*       'no-type-yet)
(define *_*            'no-type-yet)
(define *default-type* 'no-type-yet)

;*---------------------------------------------------------------------*/
;*    get-default-type ...                                             */
;*    -------------------------------------------------------------    */
;*    The default type is not a legal type that can be used in a       */
;*    foreign clause. Otherwise, the use-foreign-type! function        */
;*    implementation is incorrect.                                     */
;*---------------------------------------------------------------------*/
(define (get-default-type)
   *default-type*)

;*---------------------------------------------------------------------*/
;*    set-default-type! ...                                            */
;*---------------------------------------------------------------------*/
(define (set-default-type! type)
   (set! *default-type* type))

;*---------------------------------------------------------------------*/
;*    get-object-type ...                                              */
;*---------------------------------------------------------------------*/
(define (get-object-type)
   (cond
      ((type? *object*)
       *object*)
      (else
       (set! *object* (find-type 'object))
       *object*)))

==> bigloo_2.4b.orig.tar.gz: bigloo2.4b/comptime/Type/cache.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Type/cache.scm              */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Jan 18 11:28:43 1995                          */
;*    Last change :  Wed Jun  6 12:54:48 2001 (serrano)                */
;*    Copyright   :  1995-2001 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    A small type cache to avoid to many lookup in Tenv.              */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module type_cache
   (import type_type
	   type_env)
   (export (install-type-cache!)
           *obj*
           *cobj*
	   *cell*
	   *magic*
	   *void*
	   *bint*
	   *int*
	   *long*
	   *blong*
	   *bool*
	   *bbool*
	   *real*
	   *breal*
	   *char*
	   *bchar*
	   *bnil*
	   *pair*
	   *epair*
	   *pair-nil*
	   *string*
	   *bstring*
	   *ucs2string*
	   *symbol*
	   *keyword*
	   *vector*
	   *struct*
	   *unspec*
	   *procedure*
	   *exit*
	   *_*
	   (get-default-type::type)
	   (set-default-type! ::type)
	   (get-object-type)
	   (get-default-c-type::type)))

;*---------------------------------------------------------------------*/
;*    install-type-cache! ...                                          */
;*---------------------------------------------------------------------*/
(define (install-type-cache!)
   (set! *obj*        (use-type! 'obj #f))
   (set! *cobj*       (use-type! 'cobj #f))
   (set! *cell*       (use-type! 'cell #f))
   (set! *magic*      (use-type! 'magic #f))
   (set! *void*       (use-type! 'void #f))
   (set! *bint*       (use-type! 'bint #f))
   (set! *int*        (use-type! 'int #f))
   (set! *long*       (use-type! 'long #f))
   (set! *blong*      (use-type! 'blong #f))
   (set! *bool*       (use-type! 'bool #f))
   (set! *bbool*      (use-type! 'bbool #f))
   (set! *real*       (use-type! 'double #f))
   (set! *breal*      (use-type! 'real #f))
   (set! *char*       (use-type! 'uchar #f))
   (set! *bchar*      (use-type! 'bchar #f))
   (set! *pair*       (use-type! 'pair #f))
   (set! *epair*      (use-type! 'epair #f))
   (set! *pair-nil*   (use-type! 'pair-nil #f))
   (set! *bnil*       (use-type! 'nil #f))
   (set! *string*     (use-type! 'string #f))
   (set! *bstring*    (use-type! 'bstring #f))
   (set! *ucs2string* (use-type! 'ucs2string #f))
   (set! *symbol*     (use-type! 'symbol #f))
   (set! *keyword*    (use-type! 'keyword #f))
   (set! *vector*     (use-type! 'vector #f))
   (set! *struct*     (use-type! 'struct #f))
   (set! *procedure*  (use-type! 'procedure #f))
   (set! *unspec*     (use-type! 'unspecified #f))
   (set! *exit*       (use-type! 'exit #f))
   (set! *object*     (if (type-exists? 'object)
			  (find-type 'object)
			  #f))
   (set! *_*          (use-type! '_ #f))
   (set! *default-type* *_*))

;*---------------------------------------------------------------------*/
;*    The register cache                                               */
;*---------------------------------------------------------------------*/
(define *obj*          'no-type-yet)
(define *cobj*         'no-type-yet)
(define *cell*         'no-type-yet)
(define *magic*        'no-type-yet)
(define *void*         'no-type-yet)
(define *bint*         'no-type-yet)
(define *int*          'no-type-yet)
(define *long*         'no-type-yet)
(define *blong*        'no-type-yet)
(define *bool*         'no-type-yet)
(define *bbool*        'no-type-yet)
(define *real*         'no-type-yet)
(define *breal*        'no-type-yet)
(define *char*         'no-type-yet)
(define *bchar*        'no-type-yet)
(define *string*       'no-type-yet)
(define *bstring*      'no-type-yet)
(define *ucs2string*   'no-type-yet)
(define *symbol*       'no-type-yet)
(define *keyword*      'no-type-yet)
(define *pair*         'no-type-yet)
(define *epair*        'no-type-yet)
(define *pair-nil*     'no-type-yet)
(define *bnil*         'no-type-yet)
(define *vector*       'no-type-yet)
(define *struct*       'no-type-yet)
(define *procedure*    'no-type-yet)
(define *unspec*       'no-type-yet)
(define *exit*         'no-type-yet)
(define *object*       'no-type-yet)
(define *_*            'no-type-yet)
(define *default-type* 'no-type-yet)

;*---------------------------------------------------------------------*/
;*    get-default-type ...                                             */
;*    -------------------------------------------------------------    */
;*    The default type is not a legal type that can be used in a       */
;*    foreign clause. Otherwise, the use-foreign-type! function        */
;*    implementation is incorrect.                                     */
;*---------------------------------------------------------------------*/
(define (get-default-type)
   *default-type*)

;*---------------------------------------------------------------------*/
;*    set-default-type! ...                                            */
;*---------------------------------------------------------------------*/
(define (set-default-type! type)
   (set! *default-type* type))

;*---------------------------------------------------------------------*/
;*    get-object-type ...                                              */
;*---------------------------------------------------------------------*/
(define (get-object-type)
   (cond
      ((type? *object*)
       *object*)
      (else
       (set! *object* (find-type 'object))
       *object*)))

;*---------------------------------------------------------------------*/
;*    get-default-c-type ...                                           */
;*    -------------------------------------------------------------    */
;*    The default type for extern function.                            */
;*---------------------------------------------------------------------*/
(define (get-default-c-type)
   *int*)
